var mori = require('mori'),
		utils = require('./utils'),
		styles = require('./styles'),
		JsonMLElement = require('./jsonml-element');

var Formatter = {

		header: function (object) {

				if (utils.guard(object)) { return null; }

				var header = new JsonMLElement('span');
				header.createTextChild(utils.description(object));
				return header.toJsonML();
		},

		hasBody: function (object) {

				if (utils.guard(object)) { return false; }
				return utils.hasChildren(object);
		},

		body: function (object) {

				if (utils.guard(object)) { return null; }

		    var body = new JsonMLElement('ol');
		    var children = utils.children(object);

		    body.setStyle(styles.span);

				if (mori.isVector(object) || mori.isSet(object) ||
						mori.isList(object)) {

						utils.processChildren(body, children,
							function (nameSpan, child, i) {

									nameSpan.createTextChild(i + ': ');
							},
							function (objectTag, child) {

									if (utils.guard(object)) {

											objectTag.createTextChild('' + child);
									}
									else {

											objectTag.createObjectTag(utils.guardUndefToNull(child));
									}
							});
				}

				if (mori.isMap(object)) {

						utils.processChildren(body, children,
							function (nameSpan, child, i) {

									nameSpan.createTextChild(mori.getIn(child, [0]) + ': ');
							},
							function (objectTag, child) {

									var val = mori.getIn(child, [1]);

									if (utils.guard(object)) {

											objectTag.createTextChild('' + val);
									}
									else {

											objectTag.createObjectTag(utils.guardUndefToNull(val));
									}
							});
				}

		    return body.toJsonML();
		}
};

module.exports = Formatter;
