var mori = require('mori'),
		styles = require('./styles');

var setC = mori.set().constructor;
var mapC = mori.hashMap().constructor;

function guard (object) {

		return !(mori.isVector(object) || mori.isMap(object) ||
						 mori.isSet(object) || mori.isList(object));
}

function processChildren (parent, children, keyFn, valFn) {

		var i = 0;

		mori.each(children, function (child) {

				var li = parent.createChild('li');
				var objectTag = li.createChild('span');
				var nameSpan = objectTag.createChild('span');

				keyFn(nameSpan, child, i);
				nameSpan.setStyle(styles.color);

				valFn(objectTag, child);

				i++;
		});
}

function description (object) {

		if (mori.isVector(object)) { return 'Vector'; }

		if (mori.isMap(object)) {

				if (object.constructor === mapC) { return 'Map'; }
				else { return 'SortedMap'; }
		}

		if (mori.isSet(object)) {

				if (object.constructor === setC) { return 'Set'; }
				else { return 'SortedSet'; }
		}

		if (mori.isList(object)) { return 'List'; }

		return object;
}

function hasChildren (object) {

		if (guard(object)) { return false; }

		return Boolean(mori.count(object));
}

function children (object) {

		if (mori.isVector(object) || mori.isSet(object) || mori.isList(object)) {

				return object;
		}

		if (mori.isMap(object)) {

				return mori.map(mori.identity, object);
		}
}

function guardUndefToNull (val) { return val === undefined ? null : val; }

module.exports = {

		guard: guard,
		children: children,
		description: description,
		hasChildren: hasChildren,
		processChildren: processChildren,
		guardUndefToNull: guardUndefToNull
};
