var assert = require('assert');

var Formatter = require('../src/formatter'),
		mori = require('mori');

describe('Formatter', function() {

		describe('header', function() {

				it('should return valid HTML template for mori.vector header', function() {

					assert.equal(
						toStr(Formatter.header(mori.vector())),
						'["span",{},"Vector"]');
				});

				it('should return valid HTML template for mori.hashMap header', function() {

					assert.equal(
						toStr(Formatter.header(mori.hashMap())),
						'["span",{},"Map"]');
				});

				it('should return valid HTML template for mori.sortedMap header', function() {

					assert.equal(
						toStr(Formatter.header(mori.sortedMap())),
						'["span",{},"SortedMap"]');
				});

				it('should return valid HTML template for mori.set header', function() {

					assert.equal(
						toStr(Formatter.header(mori.set())),
						'["span",{},"Set"]');
				});

				it('should return valid HTML template for mori.sortedSet header', function() {

					assert.equal(
						toStr(Formatter.header(mori.sortedSet())),
						'["span",{},"SortedSet"]');
				});

				it('should return valid HTML template for mori.list header', function() {

					assert.equal(
						toStr(Formatter.header(mori.list())),
						'["span",{},"List"]');
				});
		});

		describe('body', function() {

				it('should return valid HTML template for mori.vector body', function() {

					assert.equal(
						toStr(Formatter.body(mori.vector(1, 2, 3))),
						'["ol",{"style":"list-style-type:none; padding-left: 0px; margin-top: 0px; margin-bottom: 0px; margin-left: 12px"},["li",{},["span",{},["span",{"style":"color: rgb(136, 19, 145);"},"0: "],["object",{"object":1}]]],["li",{},["span",{},["span",{"style":"color: rgb(136, 19, 145);"},"1: "],["object",{"object":2}]]],["li",{},["span",{},["span",{"style":"color: rgb(136, 19, 145);"},"2: "],["object",{"object":3}]]]]');
				});

				it('should return valid HTML template for mori.hashMap body', function() {

					assert.equal(
						toStr(Formatter.body(mori.hashMap('a', 1))),
						'["ol",{"style":"list-style-type:none; padding-left: 0px; margin-top: 0px; margin-bottom: 0px; margin-left: 12px"},["li",{},["span",{},["span",{"style":"color: rgb(136, 19, 145);"},"a: "],["object",{"object":1}]]]]');
				});

				it('should return valid HTML template for mori.sortedMap body', function() {

					assert.equal(
						toStr(Formatter.body(mori.sortedMap('b', 1, 'a', 2))),
						'["ol",{"style":"list-style-type:none; padding-left: 0px; margin-top: 0px; margin-bottom: 0px; margin-left: 12px"},["li",{},["span",{},["span",{"style":"color: rgb(136, 19, 145);"},"a: "],["object",{"object":2}]]],["li",{},["span",{},["span",{"style":"color: rgb(136, 19, 145);"},"b: "],["object",{"object":1}]]]]');
				});

				it('should return valid HTML template for mori.set body', function() {

					assert.equal(
						toStr(Formatter.body(mori.set([1, 2, 3]))),
						'["ol",{"style":"list-style-type:none; padding-left: 0px; margin-top: 0px; margin-bottom: 0px; margin-left: 12px"},["li",{},["span",{},["span",{"style":"color: rgb(136, 19, 145);"},"0: "],["object",{"object":1}]]],["li",{},["span",{},["span",{"style":"color: rgb(136, 19, 145);"},"1: "],["object",{"object":2}]]],["li",{},["span",{},["span",{"style":"color: rgb(136, 19, 145);"},"2: "],["object",{"object":3}]]]]');
				});

				it('should return valid HTML template for mori.sortedSet body', function() {

					assert.equal(
						toStr(Formatter.body(mori.sortedSet(1, 2, 3))),
						'["ol",{"style":"list-style-type:none; padding-left: 0px; margin-top: 0px; margin-bottom: 0px; margin-left: 12px"},["li",{},["span",{},["span",{"style":"color: rgb(136, 19, 145);"},"0: "],["object",{"object":1}]]],["li",{},["span",{},["span",{"style":"color: rgb(136, 19, 145);"},"1: "],["object",{"object":2}]]],["li",{},["span",{},["span",{"style":"color: rgb(136, 19, 145);"},"2: "],["object",{"object":3}]]]]');
				});

				it('should return valid HTML template for mori.list body', function() {

					assert.equal(
						toStr(Formatter.body(mori.list(1, 2, 3))),
						'["ol",{"style":"list-style-type:none; padding-left: 0px; margin-top: 0px; margin-bottom: 0px; margin-left: 12px"},["li",{},["span",{},["span",{"style":"color: rgb(136, 19, 145);"},"0: "],["object",{"object":1}]]],["li",{},["span",{},["span",{"style":"color: rgb(136, 19, 145);"},"1: "],["object",{"object":2}]]],["li",{},["span",{},["span",{"style":"color: rgb(136, 19, 145);"},"2: "],["object",{"object":3}]]]]');
				});

				it('should treat undefined value as null', function() {

					assert.equal(
						toStr(Formatter.body(mori.hashMap('a', undefined))),
						'["ol",{"style":"list-style-type:none; padding-left: 0px; margin-top: 0px; margin-bottom: 0px; margin-left: 12px"},["li",{},["span",{},["span",{"style":"color: rgb(136, 19, 145);"},"a: "],["object",{"object":null}]]]]');

					assert.equal(
						toStr(Formatter.body(mori.vector(undefined))),
						'["ol",{"style":"list-style-type:none; padding-left: 0px; margin-top: 0px; margin-bottom: 0px; margin-left: 12px"},["li",{},["span",{},["span",{"style":"color: rgb(136, 19, 145);"},"0: "],["object",{"object":null}]]]]');
				});
		});
});

function toStr (o) { return JSON.stringify(o); }
